steamid

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 8, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	UNIVERSE_INVALID uint64 = iota
	UNIVERSE_PUBLIC
	UNIVERSE_BETA
	UNIVERSE_INTERNAL
	UNIVERSE_DEV
)
const (
	INSTANCE_ALL uint64 = iota
	INSTANCE_DESKTOP
	INSTANCE_CONSOLE
	INSTANCE_WEB
)
const ACCOUNT_ID_MASK uint64 = 0xFFFFFFFF
const ACCOUNT_INSTANCE_MASK uint64 = 0x000FFFFF
const CHAT_INSTANCE_FLAGS_CLAN = (ACCOUNT_INSTANCE_MASK + 1) >> 1
const CHAT_INSTANCE_FLAGS_LOBBY = (ACCOUNT_INSTANCE_MASK + 1) >> 2
const CHAT_INSTANCE_FLAGS_MMSLOBBY = (ACCOUNT_INSTANCE_MASK + 1) >> 3

Variables

This section is empty.

Functions

This section is empty.

Types

type SteamId

type SteamId struct {
	Universe  uint64
	Type      types.Type
	Instance  uint64
	AccountId uint64
	Token     string
}

func NewSteamId

func NewSteamId(input string) (*SteamId, error)

func (*SteamId) FromIndividualAccountID

func (id *SteamId) FromIndividualAccountID(accountid uint64) *SteamId

func (*SteamId) FromTradeUrl

func (id *SteamId) FromTradeUrl(url string) error

func (SteamId) GetBigIntId

func (id SteamId) GetBigIntId() uint64

func (SteamId) GetSteam2RenderedID

func (id SteamId) GetSteam2RenderedID(newFormats ...bool) string

func (SteamId) GetSteam3RenderedID

func (id SteamId) GetSteam3RenderedID() string

func (SteamId) GetSteamID64

func (id SteamId) GetSteamID64() string

func (SteamId) IsGroupChat

func (id SteamId) IsGroupChat() bool

*

  • Checks whether the given ID is for a legacy group chat.
  • @returns {boolean}

func (SteamId) IsLobby

func (id SteamId) IsLobby() bool

*

  • Check whether the given Id is for a game lobby.
  • @returns {boolean}

func (SteamId) IsValid

func (id SteamId) IsValid() bool

*

  • Returns whether Steam would consider a given ID to be "valid".
  • This does not check whether the given ID belongs to a real account, nor does it check that the given ID is for
  • an individual account or in the public universe.
  • @returns {boolean}

func (SteamId) IsValidIndividual

func (id SteamId) IsValidIndividual() bool

*

  • Returns whether this SteamID is valid and belongs to an individual user in the public universe with a desktop instance.
  • This is what most people think of when they think of a SteamID. Does not check whether the account actually exists.
  • @returns {boolean}

func (SteamId) String

func (id SteamId) String() string

Jump to