Documentation
¶
Index ¶
- Constants
- type SteamId
- func (id *SteamId) FromIndividualAccountID(accountid uint64) *SteamId
- func (id *SteamId) FromTradeUrl(url string) error
- func (id SteamId) GetBigIntId() uint64
- func (id SteamId) GetSteam2RenderedID(newFormats ...bool) string
- func (id SteamId) GetSteam3RenderedID() string
- func (id SteamId) GetSteamID64() string
- func (id SteamId) IsGroupChat() bool
- func (id SteamId) IsLobby() bool
- func (id SteamId) IsValid() bool
- func (id SteamId) IsValidIndividual() bool
- func (id SteamId) String() string
Constants ¶
const ( UNIVERSE_INVALID uint64 = iota UNIVERSE_PUBLIC UNIVERSE_BETA UNIVERSE_INTERNAL UNIVERSE_DEV )
const ( INSTANCE_ALL uint64 = iota INSTANCE_DESKTOP INSTANCE_CONSOLE INSTANCE_WEB )
const ACCOUNT_ID_MASK uint64 = 0xFFFFFFFF
const ACCOUNT_INSTANCE_MASK uint64 = 0x000FFFFF
const CHAT_INSTANCE_FLAGS_CLAN = (ACCOUNT_INSTANCE_MASK + 1) >> 1
const CHAT_INSTANCE_FLAGS_LOBBY = (ACCOUNT_INSTANCE_MASK + 1) >> 2
const CHAT_INSTANCE_FLAGS_MMSLOBBY = (ACCOUNT_INSTANCE_MASK + 1) >> 3
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SteamId ¶
type SteamId struct {
Universe uint64
Type types.Type
Instance uint64
AccountId uint64
Token string
}
func NewSteamId ¶
func (*SteamId) FromIndividualAccountID ¶
func (*SteamId) FromTradeUrl ¶
func (SteamId) GetBigIntId ¶
func (SteamId) GetSteam2RenderedID ¶
func (SteamId) GetSteam3RenderedID ¶
func (SteamId) GetSteamID64 ¶
func (SteamId) IsGroupChat ¶
*
- Checks whether the given ID is for a legacy group chat.
- @returns {boolean}
func (SteamId) IsValid ¶
*
- Returns whether Steam would consider a given ID to be "valid".
- This does not check whether the given ID belongs to a real account, nor does it check that the given ID is for
- an individual account or in the public universe.
- @returns {boolean}
func (SteamId) IsValidIndividual ¶
*
- Returns whether this SteamID is valid and belongs to an individual user in the public universe with a desktop instance.
- This is what most people think of when they think of a SteamID. Does not check whether the account actually exists.
- @returns {boolean}
Click to show internal directories.
Click to hide internal directories.